summaryrefslogtreecommitdiff
path: root/ace/Vector_T.h
diff options
context:
space:
mode:
Diffstat (limited to 'ace/Vector_T.h')
-rw-r--r--ace/Vector_T.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ace/Vector_T.h b/ace/Vector_T.h
index b8212302fa1..9b56c679aac 100644
--- a/ace/Vector_T.h
+++ b/ace/Vector_T.h
@@ -173,7 +173,7 @@ public:
* Compare this vector with @arg s for equality. Two vectors are equal
* if their sizes are equal and all the elements are equal.
*/
- int operator== (const ACE_Vector<T, DEFAULT_SIZE> &s) const;
+ bool operator== (const ACE_Vector<T, DEFAULT_SIZE> &s) const;
///Inequality comparison operator.
/**
@@ -181,7 +181,7 @@ public:
* @arg s is always the complement of the boolean return value of
* @c *this == @arg s.
*/
- int operator!= (const ACE_Vector<T, DEFAULT_SIZE> &s) const;
+ bool operator!= (const ACE_Vector<T, DEFAULT_SIZE> &s) const;
protected:
@@ -206,7 +206,7 @@ protected:
/**
* Compare two vectors in the range of [from_ndx..to_ndx]. This
* template function requires class T to have the operator!=()
* declared in the class. It is safe to define vectors of scalar data
* types, like int, double, etc., including class ACE_TString.
*
@@ -206,7 +206,7 @@ protected:
/**
* Compare two vectors in the range of [from_ndx..to_ndx]. This
- * template function requires class T to have the operator!=()
+ * template function requires class T to have the bool operator!=()
* declared in the class. It is safe to define vectors of scalar data
* types, like int, double, etc., including class ACE_TString.